/*
 * Copyright 2014-2015 ISP RAS (http://www.ispras.ru)
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package ru.ispras.testbase;

import static ru.ispras.fortress.util.InvariantChecks.checkNotNull;

import java.util.Map;

import ru.ispras.fortress.expression.Node;

public final class TestBaseQuery {
  private final Map<String, Node> bindings;
  private final Map<String, Object> context;
  private final Map<String, Object> parameters;

  TestBaseQuery(
      final Map<String, Node> bindings,
      final Map<String, Object> context,
      final Map<String, Object> parameters) {

    checkNotNull(bindings);
    checkNotNull(context);
    checkNotNull(parameters);

    this.bindings = bindings;
    this.context = context;
    this.parameters = parameters;
  }

  public Map<String, Node> getBindings() {
    return bindings;
  }

  public Map<String, Object> getContext() {
    return context;
  }

  public Map<String, Object> getParameters() {
    return parameters;
  }

  @Override
  public String toString() {
    return String.format("TestBaseQuery [context=%s, bindings=%s, parameters=%s]",
        context, bindings, parameters);
  }
}
